@@ -1,19 +1,19 @@
 /* ----------------------------------------------------------------------------
    cbase - A C Foundation Library
-   Copyright (C) 1994-2007  Mark A Lindner
+   Copyright (C) 1994-2014  Mark A Lindner
 
    This file is part of cbase.
-   
+
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
-   
+
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
-   
+
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, see
    <http://www.gnu.org/licenses/>.
@@ -85,7 +85,7 @@ c_bool_t __C_socket_addr2sock(struct sockaddr_in *sa, const char *addr)
     memcpy((void *)&(sa->sin_addr), (void *)he.h_addr, (size_t)he.h_length);
     sa->sin_family = he.h_addrtype;
   }
-  
+
   return(TRUE);
 }
 
@@ -112,7 +112,7 @@ GETHOSTBYADDR:
       goto GETHOSTBYADDR;
     }
     else
-    {    
+    {
       C_error_set_errno(C_EADDRINFO);
       return(FALSE);
     }
@@ -130,7 +130,7 @@ GETHOSTBYADDR:
 static c_bool_t __C_socket_create(c_socket_t *s, int type)
 {
   int sd;
-  
+
   if((type < 0) || (type >= C_NET_MAXTYPE))
   {
     C_error_set_errno(C_EINVAL);
@@ -142,7 +142,7 @@ static c_bool_t __C_socket_create(c_socket_t *s, int type)
     C_error_set_errno(C_ESOCKET);
     return(FALSE);
   }
-  
+
   s->sd = sd;
   s->sfp = NULL;
   s->flags = 0;
@@ -150,7 +150,7 @@ static c_bool_t __C_socket_create(c_socket_t *s, int type)
   s->type = type;
   s->timeout = C_NET_DFL_TIMEOUT;
   s->conn_timeout = C_NET_DFL_CONN_TIMEOUT;
-  
+
   return(TRUE);
 }
 
@@ -219,7 +219,7 @@ GETHOSTBYNAME2:
     }
   }
 
-  s->laddr.sin_addr.s_addr = htonl(INADDR_ANY);      
+  s->laddr.sin_addr.s_addr = htonl(INADDR_ANY);
   s->laddr.sin_family = he.h_addrtype;
   s->laddr.sin_port = htons(port);
 
@@ -237,7 +237,7 @@ GETHOSTBYNAME2:
   }
 
   if(s->type == C_NET_TCP)
-  {    
+  {
     if(listen(s->sd, C_NET_BACKLOG) < 0)
     {
       C_error_set_errno(C_ELISTEN);
@@ -282,17 +282,17 @@ ACCEPT:
       case EWOULDBLOCK:
         C_error_set_errno(C_EBLOCKED);
         return(FALSE);
-        
+
       case EINTR:
       case ECONNABORTED:
         goto ACCEPT;
-        
+
       default:
         C_error_set_errno(C_EACCEPT);
         return(FALSE);
     }
   }
-  
+
   s->type = ms->type;
   s->state = C_NET_CONNECTED;
   s->flags = ms->flags;
@@ -302,7 +302,7 @@ ACCEPT:
 
   memcpy((void *)&(s->laddr), (void *)&(ms->laddr),
          sizeof(struct sockaddr_in));
-  
+
   return(TRUE);
 }
 
@@ -332,7 +332,7 @@ c_bool_t C_socket_accept_s(c_socket_t *s, c_socket_t *ms)
   }
 
   C_zero(s, c_socket_t);
-  
+
   return(__C_socket_accept(s, ms));
 }
 
@@ -357,13 +357,13 @@ c_bool_t C_socket_connect(c_socket_t *s, const char *host, in_port_t port)
     C_error_set_errno(C_EINVAL);
     return(FALSE);
   }
-  
+
   if(s->state != C_NET_CREATED)
   {
     C_error_set_errno(C_EBADSTATE);
     return(FALSE);
   }
-  
+
   if(!__C_socket_addr2sock(&(s->raddr), host))
   {
     C_error_set_errno(C_EADDRINFO);
@@ -390,7 +390,7 @@ CONNECT:
       case ECONNREFUSED:
         C_error_set_errno(C_ENOCONN);
         break;
-        
+
       case EINTR:
         goto CONNECT;
 
@@ -424,10 +424,10 @@ CONNECT:
           else
             C_error_set_errno(C_ETIMEOUT);
         }
-        
+
         break;
       }
-        
+
       default:
         C_error_set_errno(C_ECONNECT);
     }
@@ -460,7 +460,7 @@ c_bool_t C_socket_shutdown(c_socket_t *s, uint_t how)
     C_error_set_errno(C_EINVAL);
     return(FALSE);
   }
-  
+
   if(s->state != C_NET_CONNECTED)
   {
     C_error_set_errno(C_EBADSTATE);
@@ -492,7 +492,7 @@ static c_bool_t __C_socket_destroy(c_socket_t *s)
     C_error_set_errno(C_EBADSTATE);
     return(FALSE);
   }
-  
+
   if(s->sfp)
     fclose(s->sfp);
 
@@ -520,7 +520,7 @@ c_bool_t C_socket_destroy(c_socket_t *s)
 
 c_bool_t C_socket_destroy_s(c_socket_t *s)
 {
-  
+
   return(__C_socket_destroy(s));
 }
 
@@ -535,19 +535,19 @@ c_bool_t C_socket_fopen(c_socket_t *s, int buffering)
     C_error_set_errno(C_EINVAL);
     return(FALSE);
   }
-  
+
   if(s->state != C_NET_CONNECTED)
   {
     C_error_set_errno(C_EBADSTATE);
     return(FALSE);
   }
-  
+
   if(s->type != C_NET_TCP)
   {
     C_error_set_errno(C_EBADTYPE);
     return(FALSE);
   }
-  
+
   if(!(s->sfp = fdopen(s->sd, "r+")))
   {
     C_error_set_errno(C_EFDOPEN);
@@ -559,7 +559,7 @@ c_bool_t C_socket_fopen(c_socket_t *s, int buffering)
     C_error_set_errno(C_EINVAL);
     return(FALSE);
   }
-  
+
   return(TRUE);
 }
 
@@ -574,19 +574,19 @@ c_bool_t C_socket_get_peeraddr(c_socket_t *s, char *buf, size_t bufsz)
     C_error_set_errno(C_EINVAL);
     return(FALSE);
   }
-  
+
   if(s->state != C_NET_CONNECTED)
   {
     C_error_set_errno(C_EBADSTATE);
     return(FALSE);
   }
-  
+
   if(!__C_socket_sock2addr(&(s->raddr), buf, bufsz))
   {
     C_error_set_errno(C_EADDRINFO);
     return(FALSE);
   }
-  
+
   return(TRUE);
 }
 
@@ -607,7 +607,7 @@ c_bool_t C_socket_fclose(c_socket_t *s)
     fclose(s->sfp);
     s->sfp = NULL;
   }
-  
+
   return(TRUE);
 }
 
@@ -624,7 +624,7 @@ static c_bool_t __C_socket_reopen(c_socket_t *s, int sd)
     C_error_set_errno(C_EINVAL);
     return(FALSE);
   }
-  
+
   if((flags = fcntl(sd, F_GETFL, 0)) == -1)
   {
     C_error_set_errno(C_EFCNTL);
@@ -639,8 +639,8 @@ static c_bool_t __C_socket_reopen(c_socket_t *s, int sd)
     C_error_set_errno(C_ESOCKINFO);
     return(FALSE);
   }
-  
-  for(i = 0; i < C_NET_MAXTYPE; i++)
+
+  for(i = 0; i < C_NET_MAXTYPE; ++i)
     if(type == __C_net_socktypes[i]) break;
   if(i == C_NET_MAXTYPE)
   {
@@ -671,7 +671,7 @@ static c_bool_t __C_socket_reopen(c_socket_t *s, int sd)
       case ENOTCONN:
         s->state = C_NET_CREATED;
         break;
-        
+
       default:
         C_error_set_errno(C_ESOCKINFO);
         return(FALSE);
@@ -732,7 +732,7 @@ c_bool_t C_socket_set_option(c_socket_t *s, uint_t option, c_bool_t flag,
   switch(option)
   {
     /* block */
-    
+
     case C_NET_OPT_BLOCK:
     {
       int flags;
@@ -742,13 +742,13 @@ c_bool_t C_socket_set_option(c_socket_t *s, uint_t option, c_bool_t flag,
         C_error_set_errno(C_EBADSTATE);
         return(FALSE);
       }
-      
+
       if((flags = fcntl(s->sd, F_GETFL, 0)) == -1)
       {
         C_error_set_errno(C_EFCNTL);
         return(FALSE);
       }
-      
+
       flag ? (flags &= ~O_NONBLOCK) : (flags |= O_NONBLOCK);
       flag ? (s->flags &= ~C_NET_MUNBLOCK) : (s->flags |= C_NET_MUNBLOCK);
       if(fcntl(s->sd, F_SETFL, flags) == -1)
@@ -761,7 +761,7 @@ c_bool_t C_socket_set_option(c_socket_t *s, uint_t option, c_bool_t flag,
     }
 
     /* linger */
-      
+
     case C_NET_OPT_LINGER:
     {
       struct linger l;
@@ -779,23 +779,23 @@ c_bool_t C_socket_set_option(c_socket_t *s, uint_t option, c_bool_t flag,
     }
 
     /* reuse address */
-      
+
     case C_NET_OPT_REUSEADDR:
     {
       int v = flag;
-      
+
       if(setsockopt(s->sd, SOL_SOCKET, SO_REUSEADDR, (char *)&v, sizeof(int))
          != 0)
       {
         C_error_set_errno(C_ESOCKINFO);
         return(FALSE);
       }
-      
+
       return(TRUE);
     }
 
     /* oob data inline */
-    
+
     case C_NET_OPT_OOBINLINE:
     {
       int v = flag;
@@ -806,10 +806,10 @@ c_bool_t C_socket_set_option(c_socket_t *s, uint_t option, c_bool_t flag,
         C_error_set_errno(C_ESOCKINFO);
         return(FALSE);
       }
-      
-      return(TRUE);      
+
+      return(TRUE);
     }
-    
+
     /* keepalive */
 
     case C_NET_OPT_KEEPALIVE:
@@ -822,8 +822,8 @@ c_bool_t C_socket_set_option(c_socket_t *s, uint_t option, c_bool_t flag,
         C_error_set_errno(C_ESOCKINFO);
         return(FALSE);
       }
-      
-      return(TRUE);      
+
+      return(TRUE);
     }
 
     /* recv buffer */
@@ -838,8 +838,8 @@ c_bool_t C_socket_set_option(c_socket_t *s, uint_t option, c_bool_t flag,
         C_error_set_errno(C_ESOCKINFO);
         return(FALSE);
       }
-      
-      return(TRUE);      
+
+      return(TRUE);
     }
 
     /* send buffer */
@@ -854,12 +854,12 @@ c_bool_t C_socket_set_option(c_socket_t *s, uint_t option, c_bool_t flag,
         C_error_set_errno(C_ESOCKINFO);
         return(FALSE);
       }
-      
-      return(TRUE);      
+
+      return(TRUE);
     }
 
     /* unknown */
-      
+
     default:
       C_error_set_errno(C_EINVAL);
       return(FALSE);
@@ -897,7 +897,7 @@ c_bool_t C_socket_get_option(c_socket_t *s, uint_t option, c_bool_t *flag,
       if(getsockopt(s->sd, SOL_SOCKET, SO_LINGER, (char *)&l, &sz) != 0)
       {
         C_error_set_errno(C_ESOCKINFO);
-        return(FALSE);        
+        return(FALSE);
       }
 
       *flag = l.l_onoff ? TRUE : FALSE;
@@ -907,38 +907,38 @@ c_bool_t C_socket_get_option(c_socket_t *s, uint_t option, c_bool_t *flag,
     }
 
     /* reuse address */
-      
+
     case C_NET_OPT_REUSEADDR:
     {
       socklen_t sz = (socklen_t)sizeof(int);
       int v;
-      
+
       if(getsockopt(s->sd, SOL_SOCKET, SO_REUSEADDR, (char *)&v, &sz) != 0)
       {
         C_error_set_errno(C_ESOCKINFO);
-        return(FALSE);        
-      }      
+        return(FALSE);
+      }
 
       *flag = v ? TRUE : FALSE;
-      
+
       return(TRUE);
     }
 
     /* oob data inline */
-      
+
     case C_NET_OPT_OOBINLINE:
     {
       socklen_t sz = (socklen_t)sizeof(int);
       int v;
-      
+
       if(getsockopt(s->sd, SOL_SOCKET, SO_OOBINLINE, (char *)&v, &sz) != 0)
       {
         C_error_set_errno(C_ESOCKINFO);
-        return(FALSE);        
-      }      
+        return(FALSE);
+      }
 
       *flag = v ? TRUE : FALSE;
-      
+
       return(TRUE);
     }
 
@@ -948,15 +948,15 @@ c_bool_t C_socket_get_option(c_socket_t *s, uint_t option, c_bool_t *flag,
     {
       socklen_t sz = (socklen_t)sizeof(int);
       int v;
-      
+
       if(getsockopt(s->sd, SOL_SOCKET, SO_KEEPALIVE, (char *)&v, &sz) != 0)
       {
         C_error_set_errno(C_ESOCKINFO);
-        return(FALSE);        
-      }      
+        return(FALSE);
+      }
 
       *flag = v ? TRUE : FALSE;
-      
+
       return(TRUE);
     }
 
@@ -974,8 +974,8 @@ c_bool_t C_socket_get_option(c_socket_t *s, uint_t option, c_bool_t *flag,
       }
 
       *value = (uint_t)v;
-      
-      return(TRUE);      
+
+      return(TRUE);
     }
 
     /* send buffer */
@@ -992,8 +992,8 @@ c_bool_t C_socket_get_option(c_socket_t *s, uint_t option, c_bool_t *flag,
       }
 
       *value = (uint_t)v;
-      
-      return(TRUE);      
+
+      return(TRUE);
     }
 
     /* unknown */
@@ -1029,13 +1029,13 @@ c_bool_t C_socket_mcast_join(c_socket_t *s, const char *addr)
     C_error_set_errno(C_EBADTYPE);
     return(FALSE);
   }
-  
+
   if(! __C_socket_addr2sock(&saddr, addr))
   {
     C_error_set_errno(C_EADDRINFO);
     return(FALSE);
   }
-  
+
   memcpy(&mreq.imr_multiaddr, &(saddr.sin_addr), sizeof(struct in_addr));
   mreq.imr_interface.s_addr = htonl(INADDR_ANY);
 
@@ -1044,7 +1044,7 @@ c_bool_t C_socket_mcast_join(c_socket_t *s, const char *addr)
     C_error_set_errno(C_ESOCKINFO);
     return(FALSE);
   }
-  
+
   return(TRUE);
 }
 
@@ -1073,13 +1073,13 @@ c_bool_t C_socket_mcast_leave(c_socket_t *s, const char *addr)
     C_error_set_errno(C_EBADTYPE);
     return(FALSE);
   }
-  
+
   if(! __C_socket_addr2sock(&saddr, addr))
   {
     C_error_set_errno(C_EADDRINFO);
     return(FALSE);
   }
-  
+
   memcpy(&mreq.imr_multiaddr, &(saddr.sin_addr), sizeof(struct in_addr));
   mreq.imr_interface.s_addr = htonl(INADDR_ANY);
 
@@ -1089,7 +1089,7 @@ c_bool_t C_socket_mcast_leave(c_socket_t *s, const char *addr)
     C_error_set_errno(C_ESOCKINFO);
     return(FALSE);
   }
-  
+
   return(TRUE);
 }
 
@@ -1125,7 +1125,7 @@ c_bool_t C_socket_mcast_set_ttl(c_socket_t *s, c_byte_t ttl)
 c_bool_t C_socket_mcast_set_loop(c_socket_t *s, c_bool_t loop)
 {
   u_char flag = (u_char)loop;
-  
+
   if(!s)
   {
     C_error_set_errno(C_EINVAL);
